@@ -16,7 +16,7 @@
      along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
      SPDX-License-Identifier: AGPL3.0-or-later
-*/
+ */
 
 /**
  * @file include/gnunet_common.h
@@ -42,9 +42,6 @@
 #if HAVE_NETINET_IN_H
 #include <netinet/in.h>
 #endif
-#ifdef MINGW
-#include "winproc.h"
-#endif
 #ifdef HAVE_STDINT_H
 #include <stdint.h>
 #endif
@@ -189,11 +186,7 @@ extern "C" {
 /**
  * gcc-ism to get gcc bitfield layout when compiling with -mms-bitfields
  */
-#if MINGW
-#define GNUNET_GCC_STRUCT_LAYOUT __attribute__ ((gcc_struct))
-#else
 #define GNUNET_GCC_STRUCT_LAYOUT
-#endif
 
 /**
  * gcc-ism to force alignment; we use this to align char-arrays
@@ -216,28 +209,6 @@ extern "C" {
  */
 #define GNUNET_NORETURN __attribute__ ((noreturn))
 
-#if MINGW
-#if __GNUC__ > 3
-/**
- * gcc 4.x-ism to pack structures even on W32 (to be used before structs);
- * Using this would cause structs to be unaligned on the stack on Sparc,
- * so we *only* use this on W32 (see #670578 from Debian); fortunately,
- * W32 doesn't run on sparc anyway.
- */
-#define GNUNET_NETWORK_STRUCT_BEGIN _Pragma ("pack(push)") _Pragma ("pack(1)")
-
-/**
- * gcc 4.x-ism to pack structures even on W32 (to be used after structs)
- * Using this would cause structs to be unaligned on the stack on Sparc,
- * so we *only* use this on W32 (see #670578 from Debian); fortunately,
- * W32 doesn't run on sparc anyway.
- */
-#define GNUNET_NETWORK_STRUCT_END _Pragma ("pack(pop)")
-
-#else
-#error gcc 4.x or higher required on W32 systems
-#endif
-#else
 /**
  * Define as empty, GNUNET_PACKED should suffice, but this won't work on W32
  */
@@ -247,7 +218,6 @@ extern "C" {
  * Define as empty, GNUNET_PACKED should suffice, but this won't work on W32;
  */
 #define GNUNET_NETWORK_STRUCT_END
-#endif
 
 /* ************************ super-general types *********************** */
 
@@ -258,7 +228,7 @@ GNUNET_NETWORK_STRUCT_BEGIN
  */
 struct GNUNET_HashCode
 {
-  uint32_t bits[512 / 8 / sizeof (uint32_t)]; /* = 16 */
+  uint32_t bits[512 / 8 / sizeof(uint32_t)];  /* = 16 */
 };
 
 
@@ -268,7 +238,7 @@ struct GNUNET_HashCode
  */
 struct GNUNET_ShortHashCode
 {
-  uint32_t bits[256 / 8 / sizeof (uint32_t)]; /* = 8 */
+  uint32_t bits[256 / 8 / sizeof(uint32_t)];  /* = 8 */
 };
 
 
@@ -289,7 +259,6 @@ struct GNUNET_Uuid
  */
 struct GNUNET_MessageHeader
 {
-
   /**
    * The length of the struct (in bytes, including the length field itself),
    * in big-endian format.
@@ -331,7 +300,7 @@ struct GNUNET_OperationResultMessage
  */
 struct GNUNET_AsyncScopeId
 {
-  uint32_t bits[16 / sizeof (uint32_t)]; /* = 16 bytes */
+  uint32_t bits[16 / sizeof(uint32_t)];  /* = 16 bytes */
 };
 
 GNUNET_NETWORK_STRUCT_END
@@ -462,12 +431,12 @@ GNUNET_get_log_call_status (int caller_level,
  */
 void
 GNUNET_log_nocheck (enum GNUNET_ErrorType kind, const char *message, ...)
-  __attribute__ ((format (printf, 2, 3)));
+__attribute__ ((format (printf, 2, 3)));
 
 /* from glib */
 #if defined(__GNUC__) && (__GNUC__ > 2) && defined(__OPTIMIZE__)
 #define _GNUNET_BOOLEAN_EXPR(expr) \
-  __extension__({                  \
+  __extension__ ({                  \
     int _gnunet_boolean_var_;      \
     if (expr)                      \
       _gnunet_boolean_var_ = 1;    \
@@ -964,7 +933,7 @@ GNUNET_error_type_to_string (enum GNUNET_ErrorType kind);
                 cmd,                                         \
                 __FILE__,                                    \
                 __LINE__,                                    \
-                STRERROR (errno));                           \
+                strerror (errno));                           \
   } while (0)
 
 
@@ -983,7 +952,7 @@ GNUNET_error_type_to_string (enum GNUNET_ErrorType kind);
                      cmd,                                         \
                      __FILE__,                                    \
                      __LINE__,                                    \
-                     STRERROR (errno));                           \
+                     strerror (errno));                           \
   } while (0)
 
 
@@ -1002,7 +971,7 @@ GNUNET_error_type_to_string (enum GNUNET_ErrorType kind);
                 filename,                                                 \
                 __FILE__,                                                 \
                 __LINE__,                                                 \
-                STRERROR (errno));                                        \
+                strerror (errno));                                        \
   } while (0)
 
 
@@ -1022,7 +991,7 @@ GNUNET_error_type_to_string (enum GNUNET_ErrorType kind);
                      filename,                                                 \
                      __FILE__,                                                 \
                      __LINE__,                                                 \
-                     STRERROR (errno));                                        \
+                     strerror (errno));                                        \
   } while (0)
 
 /* ************************* endianess conversion ****************** */
@@ -1091,7 +1060,7 @@ GNUNET_ntoh_double (double d);
  *
  * @param type name of the struct or union, i.e. pass 'struct Foo'.
  */
-#define GNUNET_new(type) (type *) GNUNET_malloc (sizeof (type))
+#define GNUNET_new(type) (type *) GNUNET_malloc (sizeof(type))
 
 
 /**
@@ -1100,9 +1069,9 @@ GNUNET_ntoh_double (double d);
  */
 #define GNUNET_memcmp(a, b)       \
   ({                              \
-    const typeof (*b) *_a = (a);  \
-    const typeof (*a) *_b = (b);  \
-    memcmp (_a, _b, sizeof (*a)); \
+    const typeof (*b) * _a = (a);  \
+    const typeof (*a) * _b = (b);  \
+    memcmp (_a, _b, sizeof(*a)); \
   })
 
 
@@ -1115,7 +1084,7 @@ GNUNET_ntoh_double (double d);
 #define GNUNET_is_zero(a)           \
   ({                                \
     static const typeof (*a) _z;    \
-    memcmp ((a), &_z, sizeof (_z)); \
+    memcmp ((a), &_z, sizeof(_z)); \
   })
 
 
@@ -1147,7 +1116,7 @@ GNUNET_ntoh_double (double d);
  * @param n number of elements in the array
  * @param type name of the struct or union, i.e. pass 'struct Foo'.
  */
-#define GNUNET_new_array(n, type) (type *) GNUNET_malloc ((n) * sizeof (type))
+#define GNUNET_new_array(n, type) (type *) GNUNET_malloc ((n) * sizeof(type))
 
 /**
  * @ingroup memory
@@ -1159,7 +1128,7 @@ GNUNET_ntoh_double (double d);
  * @param type name of the struct or union, i.e. pass 'struct Foo'.
  */
 #define GNUNET_new_array_2d(n, m, type) \
-  (type **) GNUNET_xnew_array_2d_ (n, m, sizeof (type), __FILE__, __LINE__)
+  (type **) GNUNET_xnew_array_2d_ (n, m, sizeof(type), __FILE__, __LINE__)
 
 /**
  * @ingroup memory
@@ -1172,7 +1141,7 @@ GNUNET_ntoh_double (double d);
  * @param type name of the struct or union, i.e. pass 'struct Foo'.
  */
 #define GNUNET_new_array_3d(n, m, o, type) \
-  (type ***) GNUNET_xnew_array_3d_ (n, m, o, sizeof (type), __FILE__, __LINE__)
+  (type ***) GNUNET_xnew_array_3d_ (n, m, o, sizeof(type), __FILE__, __LINE__)
 
 /**
  * @ingroup memory
@@ -1305,7 +1274,7 @@ GNUNET_ntoh_double (double d);
  */
 #define GNUNET_array_grow(arr, size, tsize) \
   GNUNET_xgrow_ ((void **) &(arr),          \
-                 sizeof ((arr)[0]),         \
+                 sizeof((arr)[0]),         \
                  &size,                     \
                  tsize,                     \
                  __FILE__,                  \
@@ -1328,7 +1297,7 @@ GNUNET_ntoh_double (double d);
   do                                            \
   {                                             \
     GNUNET_array_grow (arr, size, size + 1);    \
-    (arr)[size - 1] = element;                  \
+    (arr) [size - 1] = element;                  \
   } while (0)
 
 /**
